@@ -11,8 +11,8 @@ from toolchest_client.api.exceptions import ToolchestException
 from toolchest_client.api.instance_type import InstanceType
 from toolchest_client.files import path_is_s3_uri
 from toolchest_client.tools import AlphaFold, BLASTN, Bowtie2, Bracken, CellRangerCount, ClustalO, Demucs, \
-    DiamondBlastp, DiamondBlastx, HUMAnN3, Kraken2, Lug, Megahit, Python3, Rapsearch2, Salmon, Shi7, ShogunAlign, \
-    ShogunFilter, STARInstance, Transfer, Test, Unicycler
+    DiamondBlastp, DiamondBlastx, FastQC, HUMAnN3, Kallisto, Kraken2, Lastal5, Lug, MetaPhlAn, Megahit, Python3, \
+    Rapsearch2, Salmon, Shi7, ShogunAlign, ShogunFilter, STARInstance, Transfer, Test, Unicycler
 from toolchest_client.tools.humann import HUMAnN3Mode
 
 
@@ -365,6 +365,60 @@ gzip compressed)
     return output
 
 
+def fastqc(inputs, output_path=None, tool_args="", contaminants="", adapters="", limits="", **kwargs):
+    """Runs FastQC via Toolchest.
+
+    :param inputs: Path or list of paths (client-side) to be passed in as input.
+    :param output_path: (optional) Path (client-side) to a directory where the output files will be downloaded.
+    :param tool_args: (optional) Additional arguments to be passed to FastQC.
+    :param contaminants: (optional) Path to a file to specify the list of contaminants to screen overrepresented
+    sequences against.
+    :param adapters: (optional) Path to a file to specify the list of adapter sequences which will be explicity searched
+    against the library
+    :param limits: (optional) Path to a file that the contains a set of criteria which will be used to determine the
+    warn/error limits for the various modules
+
+    Usage::
+
+        >>> import toolchest_client as toolchest
+        >>> toolchest.fastqc(
+        ...     inputs="./path/to/file.fastq",
+        ...     output_path="./path/to/directory/",
+        ... )
+
+    """
+    input_prefix_mapping = {}
+    if isinstance(inputs, str):
+        inputs = [inputs]
+    for i in inputs:
+        input_prefix_mapping[i] = {
+            "prefix": "",
+        }
+    if contaminants:
+        inputs.append(contaminants)
+        input_prefix_mapping[contaminants] = {
+            "prefix": "-c",
+        }
+    if adapters:
+        inputs.append(adapters)
+        input_prefix_mapping[adapters] = {
+            "prefix": "-a",
+        }
+    if limits:
+        inputs.append(limits)
+        input_prefix_mapping[limits] = {
+            "prefix": "-l",
+        }
+    instance = FastQC(
+        tool_args=tool_args,
+        inputs=inputs,
+        output_path=output_path,
+        **kwargs,
+    )
+    output = instance.run()
+    return output
+
+
 def humann3(inputs, output_path=None, tool_args="", mode=HUMAnN3Mode.HUMANN,
             taxonomic_profile=None, input_pathways=None, output_primary_name=None, **kwargs):
     """Runs HUMAnN 3 via Toolchest.
@@ -450,6 +504,78 @@ provided.
     return output
 
 
+def kallisto(output_path=None, inputs=[], database_name="kallisto_homo_sapiens", database_version="1",
+             tool_args="", gtf=None, chromosomes=None, **kwargs):
+    """Runs Kallisto quant via Toolchest.
+
+    :param inputs: Path or list of paths (client-side) to be passed in as input(s).
+    :param output_path: (optional) Path (client-side) to a directory where the output files will be downloaded.
+    :param tool_args: (optional) Additional arguments to be passed to Kallisto.
+    :param database_name: (optional) Name of database to use for Kallisto alignment. Defaults to the Homo sapiens DB.
+    :param database_version: (optional) Version of database to use for Kallisto alignment. Defaults to 1.
+    :type database_version: str
+    :param gtf: (optional) path to a GTF file for transcriptome information (required for --genomebam).
+    :param chromosomes: (optional) Path to a tab separated file with chromosome names and lengths.
+
+    .. note:: Single-end read inputs require --single, --fragment-length (or -l), and --sd (or -s) to be provided via
+    tool_args
+
+    Usage::
+
+        >>> import toolchest_client as toolchest
+        >>> toolchest.kallisto(
+        ...     tool_args="",
+        ...     inputs=["./path/to/input_r1.fastq", "./path/to/input_r2.fastq"],
+        ...     output_path="./path/to/output",
+        ... )
+
+    """
+
+    input_prefix_mapping = {}  # map of each input to its respective tag
+    index = 0
+    if gtf:
+        input_prefix_mapping[gtf] = {
+            "prefix": "--gtf",
+            "order": index
+        }
+        index += 1
+    if chromosomes:
+        input_prefix_mapping[gtf] = {
+            "prefix": "--chromosomes",
+            "order": index
+        }
+        index += 1
+    if isinstance(inputs, list):
+        for input_file in inputs:
+            input_prefix_mapping[input_file] = {
+                "prefix": "",
+                "order": index,
+            }
+            index += 1
+    elif isinstance(inputs, str):
+        input_prefix_mapping[inputs] = {
+            "prefix": "",
+            "order": index,
+        }
+        inputs = [inputs]
+    if gtf:
+        inputs.append(gtf)
+    if chromosomes:
+        inputs.append(chromosomes)
+
+    instance = Kallisto(
+        tool_args=tool_args,
+        inputs=inputs,
+        input_prefix_mapping=input_prefix_mapping,
+        output_path=output_path,
+        database_name=database_name,
+        database_version=database_version,
+        **kwargs,
+    )
+    output = instance.run()
+    return output
+
+
 def kraken2(output_path=None, inputs=[], database_name="standard", database_version="1",
             tool_args="", read_one=None, read_two=None, remote_database_path=None, **kwargs):
     """Runs Kraken 2 via Toolchest.
@@ -517,6 +643,43 @@ def kraken2(output_path=None, inputs=[], database_name="standard", database_vers
     return output
 
 
+def lastal5(output_path=None, output_primary_name="out.maf", inputs=[], database_name="standard_last",
+            database_version="1", tool_args="", **kwargs):
+    """Runs Last's lastal5 command via Toolchest.
+
+    :param inputs: Path or list of paths (client-side) to be passed in as input(s).
+    :param output_path: (optional) Path (client-side) to a directory where the output files will be downloaded.
+    :param output_primary_name: (optional) Name of the output file.
+    :param tool_args: (optional) Additional arguments to be passed to lastal5.
+    :param database_name: (optional) Name of database to use for lastal5 alignment.
+    :param database_version: (optional) Version of database to use for lastal5 alignment. Defaults to 1.
+    :type database_version: str
+    This must be an AWS S3 URI accessible by Toolchest.
+
+    Usage::
+
+        >>> import toolchest_client as toolchest
+        >>> toolchest.lastal5(
+        ...     tool_args="",
+        ...     inputs="./path/to/input.fastq",
+        ...     output_path="./path/to/output",
+        ... )
+
+    """
+
+    instance = Lastal5(
+        tool_args=tool_args,
+        inputs=inputs,
+        output_path=output_path,
+        output_primary_name=output_primary_name,
+        database_name=database_name,
+        database_version=database_version,
+        **kwargs,
+    )
+    output = instance.run()
+    return output
+
+
 def lug(script, tool_version, custom_docker_image_id, inputs=None, output_path=None, tool_args="",
         instance_type=InstanceType.COMPUTE_2, volume_size=8, **kwargs):
     """Runs Python via Toolchest and Lug.
@@ -626,6 +789,52 @@ def megahit(output_path=None, tool_args="", read_one=None, read_two=None, interl
     return output
 
 
+def metaphlan(inputs, output_path=None, output_primary_name='out.txt', tool_args="", **kwargs):
+    """Runs MetaPhlAn via Toolchest.
+
+    :param inputs: Path or list containing the path (client-side) to be passed in as input.
+    :param output_path: (optional) Path (client-side) to a directory where the output files will be downloaded.
+    :param output_primary_name: (optional) Name of the output file.
+    :param output_path: (optional) Path (client-side) to a directory where the output files will be downloaded.
+    :param tool_args: (optional) Additional arguments to be passed to MetaPhlAn.
+
+    Usage::
+
+        >>> import toolchest_client as toolchest
+        >>> toolchest.metaphlan(
+        ...     inputs="./path/to/file.fastq",
+        ...     output_path="./path/to/directory/",
+        ...     output_primary_name='new_name.txt'
+        ...     tool_args='',
+        ... )
+
+    """
+
+    if "--input_type" not in tool_args:
+        input_path = inputs
+        if not isinstance(input_path, str):
+            input_path = inputs[0]
+
+        if 'fastq' in input_path:
+            tool_args += " --input_type fastq"
+        elif 'bowtie2' in input_path:
+            tool_args += " --input_type bowtie2out"
+        elif 'fasta' in input_path:
+            tool_args += " --input_type fasta"
+        elif 'sam' in input_path:
+            tool_args += " --input_type sam"
+
+    instance = MetaPhlAn(
+        tool_args=tool_args,
+        inputs=inputs,
+        output_path=output_path,
+        output_primary_name=output_primary_name,
+        **kwargs,
+    )
+    output = instance.run()
+    return output
+
+
 def python3(script, inputs=None, output_path=None, tool_args="", custom_docker_image_id=None,
             instance_type=InstanceType.COMPUTE_2, volume_size=8, **kwargs):
     """Runs Python via Toolchest. This a restricted tool, running it requires you to request access.
