@@ -423,12 +423,38 @@ TOOL_ARG_LISTS = {
             "-n": 1,
         },
     },
+    "fastqc": {
+        "whitelist": {
+            # This allows all args that are not in the blacklist if this is the only whitelisted arg
+            "*": 0
+        },
+        "blacklist": [
+            "-o",
+            "--outdir",
+            "-h",
+            "--help",
+            "-v",
+            "--version"
+            "-j",
+            "--java",
+            "-t",
+            "--threads",
+            "-d",
+            "--dir",
+            "-c",
+            "--contaminants",
+            "-a",
+            "--adapters",
+            "-l",
+            "--limits",
+        ]
+    },
     "humann3": {
         "whitelist": {
             # This allows all args that are not in the blacklist if this is the only whitelisted arg
             "*": 0
         },
-        "blacklist": [  # Toolchest only allows non-interactive script execution
+        "blacklist": [
             "-i",
             "--input",
             "-o",
@@ -442,6 +468,21 @@ TOOL_ARG_LISTS = {
             "--input-genes"
         ]
     },
+    "kallisto": {
+        "whitelist": {
+            # This allows all args that are not in the blacklist if this is the only whitelisted arg
+            "*": 0
+        },
+        "blacklist": [
+            "-o",
+            "--output-dir",
+            "--verbose",
+            "-t",
+            "--threads",
+            "-i",
+            "--index",
+        ]
+    },
     "kraken2": {
         "whitelist": {
             "--quick": 0,
@@ -455,6 +496,15 @@ TOOL_ARG_LISTS = {
             "--report-minimizer-data": 0,
         },
     },
+    "lastal5": {
+        "whitelist": {
+            # This allows all args that are not in the blacklist if this is the only whitelisted arg
+            "*": 0
+        },
+        "blacklist": [
+            "-P"
+        ]
+    },
     "lug": {
         "whitelist": {
             # This allows all args that are not in the blacklist if this is the only whitelisted arg
@@ -492,6 +542,33 @@ TOOL_ARG_LISTS = {
             "--min-contig-len": 1,
         },
     },
+    "metaphlan": {
+        "whitelist": {
+            # This allows all args that are not in the blacklist if this is the only whitelisted arg
+            "*": 0
+        },
+        "blacklist": [
+            "-o",
+            "--output",
+            "--bowtie2out",
+            "--bowtie2db",
+            "--nproc",
+            "--force",
+            "-x",
+            "--index",
+            "--bowtie2_exe",
+            "--bowtie2_build",
+            "--tmp_dir",
+            "-s",
+            "--samout",
+            "--install",
+            "--force_download",
+            "-v",
+            "--version",
+            "-h",
+            "--help",
+        ]
+    },
     "python3": {
         "whitelist": {
             # This allows all args that are not in the blacklist if this is the only whitelisted arg
